@@ -316,6 +316,9 @@ static igraph_real_t peakx(
 static igraph_error_t brent_opt(optfun_t *f, igraph_real_t x1, igraph_real_t x2, void *extra) {
     igraph_real_t lo = x1, hi = x2;
 
+    IGRAPH_ASSERT(isfinite(lo));
+    IGRAPH_ASSERT(isfinite(hi));
+
     /* We choose the initial x3 point to be closer to x1 than x2.
      * This is so that if f1 == f2, the next computed point (newx)
      * would not coincide with x3. */
@@ -341,17 +344,24 @@ static igraph_error_t brent_opt(optfun_t *f, igraph_real_t x1, igraph_real_t x2,
     }
 
     /* It sometimes happens in disconnected graphs that the maximum is reached at or near the
-     * top of the radius range. If so, we bisect the (f3, f2) interval to search for a configuration
+     * top of the radius range. If so, we bisect the (x3, x2) interval to search for a configuration
      * where f3 >= f2. */
     if (f2 > f3) {
-        /* Limit iterations to 20 */
-        for (int i=0; i < 20; ++i) {
-            x1 = x2; f1 = f2;
+        /* Limit iterations to 'maxiter'. */
+        const int maxiter = 10;
+        int i;
+        for (i=0; i < maxiter; ++i) {
+            x1 = x3; f1 = f3;
             x3 = 0.5 * (x1 + x2);
             IGRAPH_CHECK(f(x3, &f3, extra));
 
             if (f3 >= f2) break;
         }
+        /* If no maximum was found in 'maxiter' bisections, just take the upper end of the range. */
+        if (i == maxiter) {
+            IGRAPH_CHECK(f(x2, &f2, extra));
+            return IGRAPH_SUCCESS;
+        }
     }
 
     /* Limit iterations to 20 */
@@ -468,13 +478,14 @@ static igraph_error_t get_modularity(igraph_real_t r, igraph_real_t *modularity,
  * References:
  *
  * </para><para>
- * Deritei et al, Community detection by graph Voronoi diagrams,
+ * Deritei et al., Community detection by graph Voronoi diagrams,
  * New Journal of Physics 16, 063007 (2014)
  * https://doi.org/10.1088/1367-2630/16/6/063007
  *
  * </para><para>
- * Molnár et al, Community Detection in Directed Weighted Networks using Voronoi Partitioning,
- * https://arxiv.org/abs/2304.12389
+ * Molnár et al., Community Detection in Directed Weighted Networks using Voronoi Partitioning,
+ * Scientific Reports 14, 8124 (2024)
+ * https://doi.org/10.1038/s41598-024-58624-4
  *
  * \param graph The input graph. It must be simple.
  * \param membership If not \c NULL, the membership of each vertex is returned here.
@@ -499,7 +510,8 @@ static igraph_error_t get_modularity(igraph_real_t r, igraph_real_t *modularity,
  */
 igraph_error_t igraph_community_voronoi(
         const igraph_t *graph,
-        igraph_vector_int_t *membership, igraph_vector_int_t *generators, igraph_real_t *modularity,
+        igraph_vector_int_t *membership, igraph_vector_int_t *generators,
+        igraph_real_t *modularity,
         const igraph_vector_t *lengths, const igraph_vector_t *weights,
         igraph_neimode_t mode, igraph_real_t r) {
 
@@ -622,7 +634,7 @@ igraph_error_t igraph_community_voronoi(
         IGRAPH_CHECK(choose_generators(graph, pgenerators, NULL, &local_rel_dens, &lengths2, mode, r));
         IGRAPH_CHECK(igraph_voronoi(graph, membership, NULL, pgenerators, &lengths2, mode, IGRAPH_VORONOI_RANDOM));
         if (modularity) {
-            IGRAPH_CHECK(igraph_modularity(graph, membership, weights,1,
+            IGRAPH_CHECK(igraph_modularity(graph, membership, weights, 1,
                                            mode == IGRAPH_ALL ? IGRAPH_UNDIRECTED : IGRAPH_DIRECTED, modularity));
         }
     }
