@@ -43,13 +43,12 @@ static igraph_error_t igraph_i_degree_sequence_game_configuration(igraph_t *grap
                                        const igraph_vector_int_t *in_seq) {
 
     igraph_integer_t outsum = 0, insum = 0;
-    igraph_bool_t directed = (in_seq != 0 && igraph_vector_int_size(in_seq) != 0);
+    igraph_bool_t directed = (in_seq != NULL && igraph_vector_int_size(in_seq) != 0);
     igraph_bool_t degseq_ok;
     igraph_integer_t no_of_nodes, no_of_edges;
-    igraph_integer_t *bag1 = 0, *bag2 = 0;
+    igraph_integer_t *bag1, *bag2;
     igraph_integer_t bagp1 = 0, bagp2 = 0;
     igraph_vector_int_t edges = IGRAPH_VECTOR_NULL;
-    igraph_integer_t i, j;
 
     IGRAPH_CHECK(igraph_is_graphical(out_seq, in_seq, IGRAPH_LOOPS_SW | IGRAPH_MULTI_SW, &degseq_ok));
     if (!degseq_ok) {
@@ -66,24 +65,20 @@ static igraph_error_t igraph_i_degree_sequence_game_configuration(igraph_t *grap
     no_of_edges = directed ? outsum : outsum / 2;
 
     bag1 = IGRAPH_CALLOC(outsum, igraph_integer_t);
-    if (bag1 == 0) {
-        IGRAPH_ERROR("Cannot sample with configuration model.", IGRAPH_ENOMEM); /* LCOV_EXCL_LINE */
-    }
+    IGRAPH_CHECK_OOM(bag1, "Insufficient memory for sampling from configuration model.");
     IGRAPH_FINALLY(igraph_free, bag1);
 
-    for (i = 0; i < no_of_nodes; i++) {
-        for (j = 0; j < VECTOR(*out_seq)[i]; j++) {
+    for (igraph_integer_t i = 0; i < no_of_nodes; i++) {
+        for (igraph_integer_t j = 0; j < VECTOR(*out_seq)[i]; j++) {
             bag1[bagp1++] = i;
         }
     }
     if (directed) {
         bag2 = IGRAPH_CALLOC(insum, igraph_integer_t);
-        if (bag2 == 0) {
-            IGRAPH_ERROR("Cannot sample with configuration model.", IGRAPH_ENOMEM); /* LCOV_EXCL_LINE */
-        }
+        IGRAPH_CHECK_OOM(bag2, "Insufficient memory for sampling from configuration model.");
         IGRAPH_FINALLY(igraph_free, bag2);
-        for (i = 0; i < no_of_nodes; i++) {
-            for (j = 0; j < VECTOR(*in_seq)[i]; j++) {
+        for (igraph_integer_t i = 0; i < no_of_nodes; i++) {
+            for (igraph_integer_t j = 0; j < VECTOR(*in_seq)[i]; j++) {
                 bag2[bagp2++] = i;
             }
         }
@@ -95,7 +90,7 @@ static igraph_error_t igraph_i_degree_sequence_game_configuration(igraph_t *grap
     RNG_BEGIN();
 
     if (directed) {
-        for (i = 0; i < no_of_edges; i++) {
+        for (igraph_integer_t i = 0; i < no_of_edges; i++) {
             igraph_integer_t from = RNG_INTEGER(0, bagp1 - 1);
             igraph_integer_t to = RNG_INTEGER(0, bagp2 - 1);
             igraph_vector_int_push_back(&edges, bag1[from]); /* safe, already reserved */
@@ -105,7 +100,7 @@ static igraph_error_t igraph_i_degree_sequence_game_configuration(igraph_t *grap
             bagp1--; bagp2--;
         }
     } else {
-        for (i = 0; i < no_of_edges; i++) {
+        for (igraph_integer_t i = 0; i < no_of_edges; i++) {
             igraph_integer_t from = RNG_INTEGER(0, bagp1 - 1);
             igraph_integer_t to;
             igraph_vector_int_push_back(&edges, bag1[from]); /* safe, already reserved */
@@ -171,12 +166,12 @@ static igraph_error_t igraph_i_degree_sequence_game_fast_heur_undirected(
 
     /* Outer loop; this will try to construct a graph several times from scratch
      * until it finally succeeds. */
-    finished = 0;
+    finished = false;
     while (!finished) {
         IGRAPH_ALLOW_INTERRUPTION();
 
         /* Be optimistic :) */
-        failed = 0;
+        failed = false;
 
         /* Clear the adjacency list to get rid of the previous attempt (if any) */
         igraph_adjlist_clear(&al);
@@ -231,7 +226,7 @@ static igraph_error_t igraph_i_degree_sequence_game_fast_heur_undirected(
                  * is done by enumerating all possible pairs and checking whether at
                  * least one feasible pair is found. */
                 i = 0;
-                failed = 1;
+                failed = true;
                 while (failed && igraph_set_iterate(&incomplete_vertices, &i, &from)) {
                     j = 0;
                     while (igraph_set_iterate(&incomplete_vertices, &j, &to)) {
@@ -245,7 +240,7 @@ static igraph_error_t igraph_i_degree_sequence_game_fast_heur_undirected(
                         neis = igraph_adjlist_get(&al, from);
                         if (!igraph_vector_int_binsearch(neis, to, 0)) {
                             /* Found a suitable pair, so we can continue */
-                            failed = 0;
+                            failed = false;
                             break;
                         }
                     }
@@ -319,12 +314,12 @@ static igraph_error_t igraph_i_degree_sequence_game_fast_heur_directed(igraph_t
 
     /* Outer loop; this will try to construct a graph several times from scratch
      * until it finally succeeds. */
-    finished = 0;
+    finished = false;
     while (!finished) {
         IGRAPH_ALLOW_INTERRUPTION();
 
         /* Be optimistic :) */
-        failed = 0;
+        failed = false;
 
         /* Clear the adjacency list to get rid of the previous attempt (if any) */
         igraph_adjlist_clear(&al);
@@ -383,14 +378,14 @@ static igraph_error_t igraph_i_degree_sequence_game_fast_heur_directed(igraph_t
                  * is done by enumerating all possible pairs and checking whether at
                  * least one feasible pair is found. */
                 i = 0;
-                failed = 1;
+                failed = true;
                 while (failed && igraph_set_iterate(&incomplete_out_vertices, &i, &from)) {
                     j = 0;
                     while (igraph_set_iterate(&incomplete_in_vertices, &j, &to)) {
                         neis = igraph_adjlist_get(&al, from);
                         if (from != to && !igraph_vector_int_binsearch(neis, to, 0)) {
                             /* Found a suitable pair, so we can continue */
-                            failed = 0;
+                            failed = false;
                             break;
                         }
                     }
