@@ -102,7 +102,7 @@ igraph_error_t igraph_distances_bellman_ford(const igraph_t *graph,
                       IGRAPH_EINVAL,
                       igraph_vector_size(weights), no_of_edges);
     }
-    if (no_of_edges > 0 && igraph_vector_is_any_nan(weights)) {
+    if (igraph_vector_is_any_nan(weights)) {
         IGRAPH_ERROR("Weight vector must not contain NaN values.", IGRAPH_EINVAL);
     }
 
@@ -238,12 +238,11 @@ igraph_error_t igraph_shortest_paths_bellman_ford(const igraph_t *graph,
  * \function igraph_get_shortest_paths_bellman_ford
  * \brief Weighted shortest paths from a vertex, allowing negative weights.
  *
- * This function calculates weighted shortest paths from or to a single vertex,
- * and allows negative weights. When there is more than one shortest path between
- * two vertices, only one of them is returned.
- *
- * If there are no negative weights, you are better off with
- * \ref igraph_get_shortest_paths_dijkstra() .
+ * This function calculates weighted shortest paths from or to a single vertex
+ * using the Bellman-Ford algorithm, whihc can handle negative weights. When
+ * there is more than one shortest path between two vertices, only one of them
+ * is returned. When there are no negative weights,
+ * \ref igraph_get_shortest_paths_dijkstra() is likely to be faster.
  *
  * \param graph The input graph, can be directed.
  * \param vertices The result, the IDs of the vertices along the paths.
@@ -264,6 +263,7 @@ igraph_error_t igraph_shortest_paths_bellman_ford(const igraph_t *graph,
  *    us to decrease the weight of any path containing at least a single
  *    vertex of this loop infinitely). If this is a null pointer, then the
  *    unweighted version, \ref igraph_get_shortest_paths() is called.
+ *    Edges with positive infinite weights are ignored.
  * \param mode For directed graphs; whether to follow paths along edge
  *    directions (\c IGRAPH_OUT), or the opposite (\c IGRAPH_IN), or
  *    ignore edge directions completely (\c IGRAPH_ALL). It is ignored
@@ -300,9 +300,10 @@ igraph_error_t igraph_shortest_paths_bellman_ford(const igraph_t *graph,
  * Time complexity: O(|E|*|V|), where |V| is the number of
  * vertices, |E| the number of edges.
  *
- * \sa \ref igraph_get_shortest_paths() for a faster unweighted version
- * or \ref igraph_get_shortest_paths_dijkstra() if you do not have negative
- * edge weights.
+ * \sa \ref igraph_distances_bellman_ford() to compute only shortest path
+ * lengths, but not the paths themselves; \ref igraph_get_shortest_paths() for
+ * a faster unweighted version or \ref igraph_get_shortest_paths_dijkstra()
+ * if you do not have negative edge weights.
  */
 
 igraph_error_t igraph_get_shortest_paths_bellman_ford(const igraph_t *graph,
@@ -331,6 +332,10 @@ igraph_error_t igraph_get_shortest_paths_bellman_ford(const igraph_t *graph,
                                          parents, inbound_edges);
     }
 
+    if (from < 0 || from >= no_of_nodes) {
+        IGRAPH_ERROR("Index of source vertex is out of range.", IGRAPH_EINVVID);
+    }
+
     if (igraph_vector_size(weights) != no_of_edges) {
         IGRAPH_ERROR("Weight vector length must match number of edges.", IGRAPH_EINVAL);
     }
@@ -391,7 +396,17 @@ igraph_error_t igraph_get_shortest_paths_bellman_ford(const igraph_t *graph,
         for (k = 0; k < nlen; k++) {
             igraph_integer_t nei = VECTOR(*neis)[k];
             igraph_integer_t target = IGRAPH_OTHER(graph, nei, j);
-            igraph_real_t altdist = VECTOR(dist)[j] + VECTOR(*weights)[nei];
+            igraph_real_t weight = VECTOR(*weights)[nei];
+            igraph_real_t altdist = VECTOR(dist)[j] + weight;
+
+            if (isnan(weight)) {
+                IGRAPH_ERROR("Weight vector must not contain NaN values.", IGRAPH_EINVAL);
+            }
+
+            /* infinite weights are handled correctly here; if an edge has
+             * infinite weight, altdist will also be infinite so the condition
+             * will never be true as if the edge was ignored */
+
             if (VECTOR(dist)[target] > altdist) {
                 /* relax the edge */
                 VECTOR(dist)[target] = altdist;
